# pynter

Python library for flexible workflows for atomistic calculations. Provides a `ssh` interface for high performance computing (HPC). Uses the [`pymatgen`](https://pymatgen.org) package.

It can be installed with the Python Package Index (PyPI) by running:
```sh
pip install pynter2
```

To configure settings for High-Performance Computer job submissions and for LAMMPS or VASP calculations, run:
```sh
pynter configure
```
